/*!
 * jQuery Peelback
 * Copyright 2011, Rob Flaherty
 *
 * Dual licensed under the MIT and GPL licenses
 * http://www.opensource.org/licenses/mit-license.php
 * http://www.gnu.org/licenses/gpl.html
 *
 * Modified by DPFPIC (2016)
 */
 
(function($) {
  $.Peelback = function(el, settings) {
    
    //Caching
    var base = this;
    base.$el = $(el);
    base.el = el;
    base.$el.data("Peelback", base);
    
    //Main stuff    
    base.init = function() {
      
      //Vars
      var peelHTML, peelImage, peelMask, clickWindow, hWindow, wWindow, noFollow, smallSize, bigSize, smallMaskSize, bigMaskSize;
      
      //Defaults, meet Settings
      base.settings = $.extend({},$.Peelback.defaultSettings, settings);      
      
      //If ad image is missing, stop the show            
      if (typeof(base.settings.adImage) !== 'string' || base.settings.adImage === '') {
        if ( base.settings.debug === true) {
          console.log('Ad image missing');
        }
        return;
      }
      
      //If peel image is missing, stop the show            
      if (typeof(base.settings.peelImage) !== 'string' || base.settings.peelImage === '') {
        if ( base.settings.debug === true) {
          console.log('Peel effect image missing');              
        }
        return;
      }
      
      //If click URL is missing, stop the show            
      if (typeof(base.settings.clickURL) !== 'string' || base.settings.clickURL === '') {
        if ( base.settings.debug === true) {
          console.log('Click URL missing');              
        }
        return;
      }
      
      //Convenience vars and set mask size
      smallSize = base.settings.smallSize + 'px';
      bigSize = base.settings.bigSize + 'px';
      smallMaskSize = (base.settings.smallSize - 3) + 'px';
      bigMaskSize = Math.floor((base.settings.bigSize * 0.96)) + 'px';
	  var rel;
	  
	  if (base.settings.noFollow === true) {
		  rel = 'rel="nofollow"';
	  } else {
		  rel = '';
	  }

      //Assemble
      peelHTML = $('<div id="peelback"><a href="' + base.settings.clickURL + '" target="' + base.settings.Target + '" ' + rel +'><img src="' + base.settings.peelImage +'" alt="" border="0" /></a><div></div></div>');
      peelImage = peelHTML.find('img');
      peelMask = peelHTML.find('div');
	  
		  $(peelImage).css({
			'width': '0',
			'height': '0',
			'z-index': '9001',
			'position': 'absolute',
			'top': '0',
			'-ms-interpolation-mode': 'bicubic'
		  });
		  
          $(peelMask).css({
			'width': '0',
			'height': '0',
			'overflow': 'hidden',
			'position': 'absolute',
			'top': '0',
			'z-index': '9000',
			'background': 'url(' + base.settings.adImage + ') no-repeat right top'
		  });
		  
		  if (base.settings.hPosition == 'right') {
			$(peelImage).css({
				'right': '0',
			});
			$(peelMask).css({
				'right': '0',
			});
		  } else {
			$(peelImage).css({
				'left': '0',
			});
			$(peelMask).css({
				'left': '0',
			});  			
		  }
    
      //Insert
      base.$el.prepend(peelHTML);
      
      //Auto animate option      
      if (base.settings.autoAnimate === false) {
        $(peelImage).css({ 'width' : smallSize, 'height' : smallSize });
        $(peelMask).css({ 'width' : smallMaskSize, 'height' : smallMaskSize });
      } else {
        $(peelImage).delay(500).animate({
          width: smallSize, 
          height: smallSize
        }, 500);
          
        $(peelMask).delay(500).animate({
          width: smallMaskSize, 
          height: smallMaskSize
        }, 500); 
      }      
      
      //Hover behavior
      peelHTML.hover(
        
        //Mouseover
        function() {      
          $(peelImage).stop().animate({
            width: bigSize, 
            height: bigSize
          }, 800);
          
          $(peelMask).stop().animate({
            width: bigSize, 
            height: bigMaskSize
          }, 800);
        },
        
        //Mouseout
        function() {
          $(peelImage).stop().animate({
            width: smallSize,
            height: smallSize
          }, 800);
          
          $(peelMask).stop().animate({
            width: smallMaskSize,
            height: smallMaskSize
          }, 800);
        }
      
      );
	  
	  //Windows option      
      if (base.settings.clickWindow === true) {
	  // upon clicking a peel button
	  jQuery('#peelback a').click(function(event){

		// don't go the the href yet
		event.preventDefault();
		

    		// prepare popup window
    		var left   = (jQuery(window).width()  - base.settings.wWindow)  / 2,
    		    top    = (jQuery(window).height() - base.settings.hWindow) / 2,
				width  = base.settings.wWindow + 1,
				height = base.settings.hWindow + 1,
    		    opts   = 'width='     + width +
    		             ',height='   + height +
    		             ',top='      + top +
    		             ',left='     + left;

    		// open the url in a smaller window
    	    window.open(jQuery(this).attr("href"), '', opts);
	  });
	  }	  
          
    };
        
    // Run initializer
    base.init();
  };
    
  $.Peelback.defaultSettings = {
	hPosition   : 'right',
    adImage     : null,
    peelImage   : null,
    clickURL    : null,
	Target		: '_blank',
    smallSize   : 100,
    bigSize     : 500,
    gaTrack     : false,
    autoAnimate : true,
	clickWindow : false,
	hWindow 	: 1024,
	wWindow		: 1024,
	nofollow	: false,
    debug       : false
  };
  
  $.fn.peelback = function(settings) {
    return this.each(function() {
      (new $.Peelback(this, settings));
    });
  };
    
})(jQuery);